@@ -1,25 +1,12 @@
 /*
-  Copyright (c) 2015-2020 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 
 */
 
 #include "categorytypecomboboxtest.h"
-#include "../src/categorytypecombobox.h"
+#include "categorytypecombobox.h"
 #include <QTest>
 
 CategoryTypeComboBoxTest::CategoryTypeComboBoxTest(QObject *parent)
@@ -44,8 +31,8 @@ void CategoryTypeComboBoxTest::shouldSetType_data()
 {
     QTest::addColumn<LoggingCategory::LoggingType>("input");
 
-    QTest::newRow("all") <<  LoggingCategory::All;
-    QTest::newRow("info") <<  LoggingCategory::Info;
+    QTest::newRow("all") << LoggingCategory::All;
+    QTest::newRow("info") << LoggingCategory::Info;
     QTest::newRow("warning") << LoggingCategory::Warning;
     QTest::newRow("critical") << LoggingCategory::Critical;
     QTest::newRow("off") << LoggingCategory::Off;
