@@ -1,20 +1,7 @@
 /*
-  Copyright (c) 2015-2020 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 
 */
 
@@ -22,26 +9,28 @@
 #include "categorytypecombobox.h"
 #include "kdebugsettingsdialog.h"
 #include "kdebugsettingsutil.h"
-#include <KLocalizedString>
-#include <QLabel>
 #include <KLineEdit>
-#include <QVBoxLayout>
-#include <QHBoxLayout>
+#include <KLocalizedString>
 #include <QCheckBox>
+#include <QHBoxLayout>
+#include <QLabel>
+#include <QVBoxLayout>
 
 ConfigureCustomSettingWidget::ConfigureCustomSettingWidget(QWidget *parent)
     : QWidget(parent)
+    , mCategoryLineEdit(new KLineEdit(this))
+    , mEnableCategory(new QCheckBox(i18n("Enable"), this))
+    , mCategoryType(new CategoryTypeComboBox(true, this))
 {
-    auto *vbox = new QVBoxLayout(this);
+    auto vbox = new QVBoxLayout(this);
 
-    QLabel *lab = new QLabel(i18n("Category:"), this);
+    auto lab = new QLabel(i18n("Category:"), this);
     lab->setObjectName(QStringLiteral("category_label"));
-    mCategoryLineEdit = new KLineEdit(this);
     mCategoryLineEdit->setTrapReturnKey(true);
     mCategoryLineEdit->setClearButtonEnabled(true);
     mCategoryLineEdit->setObjectName(QStringLiteral("category_lineedit"));
     connect(mCategoryLineEdit, &KLineEdit::textChanged, this, &ConfigureCustomSettingWidget::slotTextChanged);
-    auto *categoryLayout = new QHBoxLayout;
+    auto categoryLayout = new QHBoxLayout;
     vbox->addLayout(categoryLayout);
     categoryLayout->addWidget(lab);
     categoryLayout->addWidget(mCategoryLineEdit);
@@ -50,11 +39,9 @@ ConfigureCustomSettingWidget::ConfigureCustomSettingWidget(QWidget *parent)
     lab->setObjectName(QStringLiteral("categorytype_label"));
     categoryLayout->addWidget(lab);
 
-    mCategoryType = new CategoryTypeComboBox(true, this);
     mCategoryType->setObjectName(QStringLiteral("categorytype_combobox"));
     categoryLayout->addWidget(mCategoryType);
 
-    mEnableCategory = new QCheckBox(i18n("Enable"), this);
     mEnableCategory->setObjectName(QStringLiteral("enable_category"));
     categoryLayout->addWidget(mEnableCategory);
 }
