@@ -8,11 +8,11 @@
 #include "kdeapplicationdebugsettingpage.h"
 #include "kdeapplicationtreelistwidget.h"
 #include <KLocalizedString>
+#include <KTreeWidgetSearchLine>
 #include <QEvent>
 #include <QKeyEvent>
 #include <QPushButton>
 #include <QVBoxLayout>
-#include <ktreewidgetsearchline.h>
 
 KDEApplicationDebugSettingPage::KDEApplicationDebugSettingPage(QWidget *parent)
     : QWidget(parent)
