@@ -201,6 +201,7 @@ void KDebugSettingsDialog::slotInsertCategories()
             }
         }
         mKdeApplicationSettingsPage->insertCategories(newCategories);
+        KMessageBox::information(this, i18n("Categories from file \'%1\' inserted.", path), i18n("Insert Categories"));
     }
 }
 
@@ -213,7 +214,7 @@ void KDebugSettingsDialog::slotSaveAsGroup()
         const QString trimmedName = name.trimmed();
         if (!trimmedName.isEmpty()) {
             if (mLoadToolButton->groupNames().contains(trimmedName)) {
-                KMessageBox::error(this, i18n("%1 is already used as a group name.\nPlease save as another name.", trimmedName));
+                KMessageBox::error(this, i18n("\'%1\' is already used as a group name.\nPlease save as another name.", trimmedName));
             } else {
                 if (!QDir().mkpath(groupPath)) {
                     qCWarning(KDEBUGSETTINGS_LOG) << "Unable to create folder: " << groupPath;
